#!/usr/bin/env python
##############################################################################
#
# (c) 2024 The Trustees of Columbia University in the City of New York.
# All rights reserved.
#
# File coded by: Billinge Group members and community contributors.
#
# See GitHub contributions for a more detailed list of contributors.
# https://github.com/bobleesj-test-org/bobleesj.release/graphs/contributors
#
# See LICENSE.rst for license information.
#
##############################################################################

"""Blank namespace package for module bobleesj."""


from pkgutil import extend_path

__path__ = extend_path(__path__, __name__)

# End of file

